BoxWrite

Type Alias BoxWrite 

pub type BoxWrite = Box<dyn Write + Send + Sync + 'static>;
A type-erased boxed writer that can be sent between threads safely.

Aliased Type

pub struct BoxWrite(/* private fields */);

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 16 bytes